Erika
=====

Erika is a GTK+ podcast manager for Linux.

.. image:: https://raw.githubusercontent.com/Muges/erika/master/screenshots/main_window.png
    :target: https://raw.githubusercontent.com/Muges/erika/master/screenshots/main_window.png
    :alt: Main window of Erika

Features
--------

- Suscribe, download and listen to audio podcasts
- Keep your podcast library organised, and synchronize it with `gpodder.net`_

.. _gpodder.net: https://gpodder.net

Installation
------------

Install Python 3, PyGObject_, and webkitgtk (not webkit2gtk) and run the command ::

    pip install erika

.. _PyGObject:
    https://pygobject.readthedocs.io/en/latest/getting_started.html

Credits
-------

Erika is released under the MIT License, with the exception of the file
``erika/frontend/widgets/scrolled_window.py`` which is released under the
GNU/GPLv3 License.
